NudgeStoriesData class

Constructors

NudgeStoriesData({required Task task, required String assetUrl, int? storyIndex, int? slideIndex, bool? deepLinkMode, String? deepLinkType})

Properties

assetUrl String
final
deepLinkMode bool?
final
deepLinkType String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slideIndex int?
final
storyIndex int?
final
task Task
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited