ComponentProps class
Constructors
- ComponentProps({required bool hasCustomHtml, String? customHtml, required String asset, String? objectFit})
-
ComponentProps.fromJson(Map<
String, dynamic> json) -
factory
Properties
- asset → String
-
final
- customHtml → String?
-
final
- hasCustomHtml → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- objectFit → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited